@@ -1,5 +1,5 @@
 /* internal.h --- Internal header file for Shishi.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -39,6 +39,9 @@
 #include <sys/select.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <sys/time.h>
+#include <time.h>
+#include <signal.h>
 
 #ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
@@ -52,10 +55,6 @@
 /*extern int h_errno;*/
 #endif
 
-#ifdef HAVE_PWD_H
-#include <pwd.h>
-#endif
-
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
@@ -64,30 +63,11 @@
 #include <errno.h>
 #endif
 
-#if TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# if HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
-
-#ifdef HAVE_SIGNAL_H
-#include <signal.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
-#endif
 #ifdef HAVE_NETINET_IN6_H
 #include <netinet/in6.h>
 #endif
-#ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
-#endif
 
 #ifdef HAVE_ARPA_NAMESER_H
 #include <arpa/nameser.h>
@@ -106,6 +86,7 @@
 #include "base64.h"
 #include "getdate.h"
 #include "read-file.h"
+#include "timespec.h"
 #include "xalloc.h"
 #include "xgethostname.h"
 #include "xgetdomainname.h"
@@ -140,11 +121,6 @@
 		  SHISHI_VERBOSE_CRYPTO_NOISE)
 #define VERBOSE(h) (h->verbose & ~VERBOSES)
 
-/* For resolv.c and netio.c, on old systems. */
-#ifndef T_SRV
-# define T_SRV (33)
-#endif
-
 enum
 {
   UDP,
