@@ -1,5 +1,5 @@
 /* ccache.c --- Credential Cache compatibility ticket set handling.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -23,6 +23,8 @@
 #include "internal.h"
 #include "ccache.h"
 
+#include "utils.h"
+
 /**
  * shishi_tkts_default_ccache_guess:
  * @handle: Shishi library handle create by shishi_init().
@@ -43,7 +45,11 @@ shishi_tkts_default_ccache_guess (Shishi * handle)
   if (envfile)
     return xstrdup (envfile);
 
+#if HAVE_GETUID
   return xasprintf("/tmp/krb5cc_%u", (unsigned long) getuid ());
+#else
+  return xasprintf("/tmp/krb5cc_0");
+#endif
 }
 
 /**
@@ -327,7 +333,7 @@ shishi_tkts_add_ccache_file (Shishi * handle,
 			     Shishi_tkts *tkts)
 {
   size_t len;
-  char *ccache = read_file (filename, &len);
+  char *ccache = read_binary_file (filename, &len);
   int rc;
 
   if (!ccache)
