@@ -1,5 +1,5 @@
 /* keytab2shishi.c --- Convert MIT keytab files to Shishi hostkeys
- * Copyright (C) 2006, 2007  Simon Josefsson
+ * Copyright (C) 2006, 2007, 2008  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -32,11 +32,7 @@
 #include <errno.h>
 
 /* Get i18n. */
-#ifdef HAVE_LOCALE_H
-# include <locale.h>
-#else
-# define setlocale(Category, Locale)	/* empty */
-#endif
+#include <locale.h>
 #include <gettext.h>
 #define _(String) gettext (String)
 #define gettext_noop(String) String
