@@ -1,5 +1,5 @@
 /* shishi.c --- Shishi command line interface.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -31,11 +31,7 @@
 #include <string.h>
 
 /* Get i18n. */
-#ifdef HAVE_LOCALE_H
-# include <locale.h>
-#else
-# define setlocale(Category, Locale)	/* empty */
-#endif
+#include <locale.h>
 #include <gettext.h>
 #define _(String) gettext (String)
 #define gettext_noop(String) String
@@ -43,14 +39,39 @@
 
 #include <shishi.h>
 
-/* Get set_program_name and program_name. */
+/* Gnulib files. */
 #include "progname.h"
-
-/* Get error. */
 #include "error.h"
+#include "version-etc.h"
 
 #include "shishi_cmd.h"
 
+const char version_etc_copyright[] =
+  /* Do *not* mark this string for translation.  %s is a copyright
+     symbol suitable for this locale, and %d is the copyright
+     year.  */
+  "Copyright %s %d Simon Josefsson.";
+
+static void
+usage (int status)
+{
+  if (status != EXIT_SUCCESS)
+    fprintf (stderr, _("Try `%s --help' for more information.\n"),
+	     program_name);
+  else
+    {
+      cmdline_parser_print_help ();
+      /* TRANSLATORS: The placeholder indicates the bug-reporting address
+	 for this package.  Please add _another line_ saying
+	 "Report translation bugs to <...>\n" with the address for translation
+	 bugs (typically your translation team's web or email address).  */
+      printf (_("\nMandatory arguments to long options are "
+		"mandatory for short options too.\n\nReport bugs to <%s>.\n"),
+	      PACKAGE_BUGREPORT);
+    }
+  exit (status);
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -65,25 +86,24 @@ main (int argc, char *argv[])
   set_program_name (argv[0]);
 
   if (cmdline_parser (argc, argv, &args) != 0)
-    error (EXIT_FAILURE, 0, _("Try `%s --help' for more information."),
-	   program_name);
+    usage (EXIT_FAILURE);
+
+  if (args.version_given)
+    {
+      version_etc (stdout, "shishi", PACKAGE_NAME, VERSION,
+		   "Simon Josefsson", (char *) NULL);
+      return EXIT_SUCCESS;
+    }
 
   if (args.inputs_num > 2 ||
       args.destroy_given + args.list_given + args.renew_given > 1)
     {
       error (0, 0, _("too many arguments"));
-      error (EXIT_FAILURE, 0, _("Try `%s --help' for more information."),
-	     program_name);
+      usage (EXIT_FAILURE);
     }
 
   if (args.help_given)
-    {
-      cmdline_parser_print_help ();
-      printf (_("\nMandatory arguments to long options are "
-		"mandatory for short options too.\n\nReport bugs to <%s>.\n"),
-	      PACKAGE_BUGREPORT);
-      return EXIT_SUCCESS;
-    }
+    usage (EXIT_SUCCESS);
 
   rc = shishi_init_with_paths (&sh, args.ticket_file_arg,
 			       args.system_configuration_file_arg,
